# PolicyStatus

A policy status describes the read-only, inferred properties of the policy

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**associated_issuers** | [**[PolicyIssuerRef]**](PolicyIssuerRef.md) | Issuers which use this policy | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


